import QtQuick 1.0
import org.kde.plasma.graphicswidgets 0.1 as PlasmaWidgets
import org.kde.plasma.core 0.1 as PlasmaCore

Image {
    id: canvas;
    source: "bg.png"
    width: 800; height: 600;

    Item {
        id: welcome;
        anchors.horizontalCenter: parent.horizontalCenter;
        anchors.top: parent.top;
        anchors.topMargin: 10

        Image {
            id: logo;
            source: "kde.png"
            width: 64; height: 64;
            anchors.horizontalCenter: parent.horizontalCenter;
            anchors.top: parent.top;
        }

        Text {
            id: welcomeText;
            text: "Welcome to KDE";
            color: "white";
            font.pointSize: 18;
            style: Text.Raised;
            styleColor: "gray";
            anchors.horizontalCenter: logo.horizontalCenter;
            anchors.top: logo.bottom;
            anchors.topMargin: 10;
        }
    }


    ListModel {
        id: userModel

        ListElement {
            name: "Anna Frias"
            picture: "1.png"
        }

        ListElement {
            name: "Dan Pars"
            picture: "2.png"
        }

        ListElement {
            name: "Georgia Lee"
            picture: "3.png"
        }

        ListElement {
            name: "Frank Wittle"
            picture: "4.png"
        }

        ListElement {
            name: "Dick Warrhing"
            picture: "5.png"
        }

//         ListElement {
//             name: "Charlie Daly"
//             picture: "6.png"
//         }
    }

    Component {
        id: userDelegate
        Item {
            id: delegateItem
            width: 128
//            height: 128
            Image {
                id: image
                width: 128
                height: 128
                source: picture
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        console.log(index)
                        loginModel.append(userModel.get(index))
                        userModel.remove(index)
                    }
                }
            }

            Text {
                text: name
                anchors.horizontalCenter: image.horizontalCenter;
                anchors.top: image.bottom
                anchors.topMargin: -20
            }

            ListView.onRemove: SequentialAnimation {
                PropertyAction { target: delegateItem; property: "ListView.delayRemove"; value: true }
                NumberAnimation { target: delegateItem; property: "height"; to: 0; duration: 250; easing.type: Easing.InOutQuad }

                // Make sure delayRemove is set back to false so that the item can be destroyed
                PropertyAction { target: delegateItem; property: "ListView.delayRemove"; value: false }
            }
        }
    }

    ListView {
        id: userView
        width: parent.width
//        height: 128
//        anchors.fill: parent
        anchors.horizontalCenter: canvas.horizontalCenter;
        anchors.top: welcome.bottom
        anchors.topMargin: 100
        orientation: ListView.Horizontal
        model: userModel
        delegate: userDelegate
//        highlight: Rectangle { color: "lightsteelblue"; radius: 5 }
    }

    ListModel {
        id: loginModel
    }

    Item {
        id: loginBox
        anchors.horizontalCenter: canvas.horizontalCenter;
        anchors.top: userView.bottom
        anchors.topMargin: 100
        /// ITEM

        ListView {
            id: loginView
            anchors.horizontalCenter: parent.horizontalCenter
            width: 128
            height: 128
            anchors.top: parent.top
            anchors.topMargin: 0
            model: loginModel
            delegate: userDelegate
        }

        Row {
            spacing: 5
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: loginView.bottom

//             TextInput{
//                 text: "sdfdsfdsf"
//                 echoMode: TextInput.Password
//             }

            PlasmaWidgets.LineEdit {
                id: passwordInput;
//                 width: 250;
                height: 30;
                clickMessage: "Password";
                onReturnPressed: {}
            }

            Image {
                anchors.leftMargin: 10
                anchors.verticalCenter: passwordInput.verticalCenter
                source: "gobutton.png"
            }
        }
    }


// // // // // // // // // // FOOOOOTER


    Rectangle {
        id: footer
        anchors.horizontalCenter: canvas.horizontalCenter;
        anchors.bottom: canvas.bottom;
        anchors.bottomMargin: 10;

        Row {
            id: dateandtime
            anchors.horizontalCenter: footer.horizontalCenter
            anchors.bottom: seperator.top
            anchors.bottomMargin: 5;
            spacing: 20

            Text {
                id: date
                text: Qt.formatDate(new Date(), Qt.DefaultLocaleLongDate)
                color: "white";
                style: Text.Raised;
                styleColor: "gray";
            }

            Text {
                id: time
                text: Qt.formatTime(new Date(), Qt.DefaultLocaleLongDate)
                color: "white";
                style: Text.Raised;
                styleColor: "gray";
            }
        }

        Rectangle {
            id: seperator
            color: "white"
            width: 400
            height: 1
            anchors.horizontalCenter: parent.horizontalCenter;
            anchors.bottom: power.top
            anchors.bottomMargin: 5
        }

        Row {
            id: power
            spacing: 30
            anchors.horizontalCenter: parent.horizontalCenter;
            anchors.bottom: footer.bottom
            anchors.bottomMargin: 10

            Image {
                id: sleep
                width: 32
                height: 32
                source: "sleep.png"

                Text {
                    anchors.top: parent.bottom
                    anchors.horizontalCenter: parent.horizontalCenter;
                    text: "sleep"
                    color: "white"
                    style: Text.Raised;
                    styleColor: "gray";
                }

                MouseArea {
                    anchors.fill: parent
                    onClicked: {}
                }
            }

            Image {
                id: reboot
                width: 32
                height: 32
                source: "reboot.png"

                Text {
                    anchors.top: parent.bottom
                    anchors.horizontalCenter: parent.horizontalCenter;
                    text: "reboot"
                    color: "white"
                    style: Text.Raised;
                    styleColor: "gray";
                }

                MouseArea {
                    anchors.fill: parent
                    onClicked: {}
                }
            }

            Image {
                id: shutdown
                width: 32
                height: 32
                source: "shutdown.png"

                Text {
                    anchors.top: parent.bottom
                    anchors.horizontalCenter: parent.horizontalCenter;
                    text: "shutdown"
                    color: "white"
                    style: Text.Raised;
                    styleColor: "gray";
                }

                MouseArea {
                    anchors.fill: parent
                    onClicked: {}
                    hoverEnabled: true
                }
            }
        }
    }
}
